/************************************************************************************
****              Perodo para Apurao do Resultado Operacional                 ****
*************************************************************************************

Criado em  : 08/2007
       Por : Alessandra Cristina

Descrio:

      - Executa a procedure de apurao do resultado operacional para uma lista de
        filiais de acordo com o perodo precisto

      - Se no houver perodo parametrizado para a filial executa para a data de
        processamento da mesma.

      - Caso a filial seja uma Central Merenda(Pme) e a mesma esteja parametrizada
        suas agregadas tambm sero apuradas
Util :
       - Erro : raiserror('Mensagem', 16,1)
*/

IF EXISTS (SELECT
              *
           FROM
              SYSOBJECTS O, SYSUSERS U
           WHERE
              O.NAME = 'PERIODO_APURAC_RESOPERFILI' AND
              TYPE = 'P' 		                      AND
              U.UID = O.UID                         AND
              U.NAME = USER)

DROP PROCEDURE PERIODO_APURAC_RESOPERFILI
GO

CREATE PROCEDURE PERIODO_APURAC_RESOPERFILI
                     @P_NRLISTA     VARCHAR(20)

AS

   DECLARE @V_COUNT        NUMERIC(15,5);
   DECLARE @V_DTINICIAL    DATETIME;
   DECLARE @V_DTFINAL      DATETIME;
   DECLARE @V_FILIAL       VARCHAR(4);
   DECLARE @V_CDLISTA      VARCHAR(20);
   DECLARE @V_IDFILIALAGRROP VARCHAR(1);
   DECLARE @V_CDFILCENTPME   VARCHAR(4);
   DECLARE @V_CDFILCENTAUX   VARCHAR(4);
   DECLARE @V_IDTPAPURACAO   VARCHAR(1);
   
BEGIN
   SET @V_IDFILIALAGRROP = '';
   SET @V_CDFILCENTPME = '';
   SET @V_CDFILCENTAUX = '';

   DECLARE C_FILIAL CURSOR FOR
      SELECT DISTINCT CDFILIAL, CDLISTA, IDFILIALAGRROP, CDFILCENTPME
                    FROM ( SELECT F.CDFILIAL, CDLISTA, IDFILIALAGRROP, CDFILCENTPME
                              FROM LISTA L, FILIAL F, PARFILIALROP P, PARAMGERAL G
                              WHERE
                                    (NRLISTA       = @P_NRLISTA)   AND
                                    (CDLISTA       = P.CDFILIAL)  AND
                                    (ISNULL(IDUTPADRROP,'N')   <> 'S')          AND
                                    ((CDLISTA      = F.CDFILIAL)
                                      OR ((CDFILCENTPME = CDLISTA)
                                      AND (IDFILIALAGRROP = 'S')))
                               UNION ALL

                               SELECT F.CDFILIAL, CDLISTA, IDFILIALAGRROP, CDFILCENTPME
                               FROM LISTA L, FILIAL F, PARFILIALROP P, PARAMGERAL G
                               WHERE
                                 (NRLISTA       = @P_NRLISTA)  AND
                                 (P.CDFILIAL    = 'P')         AND
                                 (ISNULL(IDUTPADRROP,'N') = 'S')           AND
                                 ((CDLISTA      = F.CDFILIAL)
                                   OR ((CDFILCENTPME = CDLISTA)
                                   AND (IDFILIALAGRROP = 'S')))

                               ) A
                               ORDER BY CDFILCENTPME,CDLISTA, CDFILIAL;

   OPEN C_FILIAL;
   FETCH NEXT FROM C_FILIAL INTO @V_FILIAL, @V_CDLISTA, @V_IDFILIALAGRROP, @V_CDFILCENTPME;
   WHILE (@@FETCH_STATUS = 0) BEGIN
      IF (@V_CDFILCENTPME IS NOT NULL) AND (@V_IDFILIALAGRROP = 'S') AND
         (@V_CDFILCENTPME <> @V_CDFILCENTAUX)  BEGIN

         SET @V_CDFILCENTAUX = @V_CDFILCENTPME;

         SELECT @V_DTINICIAL = ISNULL(DTINIAPURACROP, CASE IDUTILDTPROC WHEN 'S' THEN DTPROCESSA ELSE GETDATE() END),
                @V_DTFINAL   = ISNULL(DTFINAPURACROP, CASE IDUTILDTPROC WHEN 'S' THEN DTPROCESSA ELSE GETDATE() END)
           FROM PARAMGERAL, PARAMFILIAL P
           LEFT JOIN APURACAOROP A
             ON (P.CDFILIAL  = A.CDFILIAL)
          WHERE (P.CDFILIAL  = @V_CDFILCENTPME);
      END
      ELSE BEGIN
         SELECT @V_DTINICIAL = ISNULL(DTINIAPURACROP, CASE IDUTILDTPROC WHEN 'S' THEN DTPROCESSA ELSE GETDATE() END),
                @V_DTFINAL   = ISNULL(DTFINAPURACROP, CASE IDUTILDTPROC WHEN 'S' THEN DTPROCESSA ELSE GETDATE() END)
           FROM PARAMGERAL, PARAMFILIAL P
           LEFT JOIN APURACAOROP A
             ON (P.CDFILIAL  = A.CDFILIAL)
          WHERE (P.CDFILIAL  = @V_CDLISTA);
      END;

      UPDATE APURACAOROP
      SET DTINIAPURACROP  = @V_DTFINAL + 1,
          DTFINAPURACROP  = @V_DTFINAL + 1
      WHERE CDFILIAL = @V_FILIAL;


      SELECT  @V_COUNT = COUNT(*)
        FROM  PARFILIALROP
        WHERE CDFILIAL = @V_FILIAL;

      IF @V_COUNT = 0 BEGIN
         SET @V_IDTPAPURACAO = '1';
      END
      ELSE BEGIN
         SELECT  @V_IDTPAPURACAO = IDTPAPURACAO
           FROM  PARFILIALROP
           WHERE CDFILIAL = @V_FILIAL;
      END;

      IF (@V_IDTPAPURACAO = '1') OR (@V_IDTPAPURACAO = '3') BEGIN
         EXEC APURAC_RESOPERFILI @V_FILIAL, @V_DTINICIAL, @V_DTFINAL, 'N';
      END;
     /*
      IF (@V_IDTPAPURACAO = '2') OR (@V_IDTPAPURACAO = '3') BEGIN
         EXEC APURAC_RESOPERFILI_DRF @V_FILIAL, @V_DTINICIAL, @V_DTFINAL, 'N';
      END; */

      FETCH NEXT FROM C_FILIAL INTO @V_FILIAL, @V_CDLISTA, @V_IDFILIALAGRROP, @V_CDFILCENTPME;
   END;
   DEALLOCATE C_FILIAL;
END;
GO

-- VERSAO --
EXEC  ATUVEROBJ 'PERIODO_APURAC_RESOPERFILI','5.05.171';
GO

