package com.javaseleniumtemplate.tests;

import com.javaseleniumtemplate.bases.TestBase;
import com.javaseleniumtemplate.dbsteps.DBSteps;
import com.javaseleniumtemplate.flows.LancamentoEntradaFlows;
import com.javaseleniumtemplate.flows.LoginFlows;
import com.javaseleniumtemplate.flows.MainFlows;
import com.javaseleniumtemplate.pages.LancamentoEntradaPages;
import com.javaseleniumtemplate.pages.MainPage;
import org.testng.Assert;
import org.testng.annotations.Test;

import static com.javaseleniumtemplate.GlobalParameters.DATA_VALIDADE;


public class LancamentoEntradaTests extends TestBase {
    MainPage mainPage;
    LoginFlows loginflows;
    MainFlows mainflows;
    LancamentoEntradaFlows lancamentoEntradaFlows;
    LancamentoEntradaPages lancamentoEntradaPages;

    @Test
    public void lancamentoEntradaComChaveSemRelacionamentoParaValidarAtualizacaoDeEstoque() {

        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String chaveDeAcesso = DBSteps.retornaChaveCSV();
        String statusEsperado = "Pendente";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaPages.preencherChave(chaveDeAcesso);
        lancamentoEntradaFlows.salvarLancEntrada();
        String quantidadeProdNF = lancamentoEntradaPages.quantidadeProduto().replace(",0000", "");
        lancamentoEntradaFlows.preencheDataValidade();
        String lote = lancamentoEntradaPages.lote();
        lancamentoEntradaFlows.confirmar();
        lancamentoEntradaPages.popupNao();
        lancamentoEntradaPages.fecharNF();
        lancamentoEntradaPages.clicarConfirmaFechamento();
        lancamentoEntradaPages.popUpClicarEmOK();
        lancamentoEntradaPages.tabMensagemFechamento();
        lancamentoEntradaPages.clicarConfirmaFechamento();
        String quantidadeBd = DBSteps.retornaQuantidadeEstoque(lote);
        String statusAtual = lancamentoEntradaPages.retornarStatusLancamento();
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);
        Assert.assertEquals(quantidadeProdNF, quantidadeBd);
        Assert.assertEquals(statusEsperado, statusAtual);
    }

    @Test
    public void lancamentoEntradaComChaveEComRelacionamento(){
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String chaveDeAcesso = DBSteps.retornaChaveCSVRelacionamento();
        String procuraRelacionamento = "Hela Poul";
        String procuraRelacionamentoTres = "AGUA MINE";
        String mensagemEsperada = "Nota fechada com sucesso!";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaPages.preencherChave(chaveDeAcesso);
        lancamentoEntradaPages.clicarSalvarLancEntrada();
        lancamentoEntradaFlows.relacionaProdutoUm(procuraRelacionamento);
        lancamentoEntradaFlows.relacionaProdutoDois(procuraRelacionamento);
        lancamentoEntradaFlows.relacionaProdutoTres(procuraRelacionamentoTres);
        lancamentoEntradaFlows.confirmarRelac();
        lancamentoEntradaFlows.preencheDataValidade();
        lancamentoEntradaPages.clicarConfirmarInfoComplementar();
        lancamentoEntradaFlows.preencheDataValidade();
        lancamentoEntradaFlows.confirmar();
        lancamentoEntradaPages.popupNao();
        lancamentoEntradaFlows.fechaNotaFiscal();

        String mensagemAtual = lancamentoEntradaPages.capturaMensagemFechamento();

        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);

        Assert.assertEquals(mensagemEsperada, mensagemAtual);
        DBSteps.apagaRelacionamentoProdXProdXml();
    }

    @Test
    public void lancamentoEntradaComChaveCTESemRelacionamento(){
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String chaveDeAcesso = DBSteps.retornaChaveCSVCte();
        String entradaOperacao = "CTE";
        String mensagemEsperada = "Nota fechada com sucesso!";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaPages.clicaOperacao();
        lancamentoEntradaPages.procuraOperacao(entradaOperacao);
        lancamentoEntradaPages.selecionaOperacao();
        lancamentoEntradaPages.preencherChave(chaveDeAcesso);
        lancamentoEntradaPages.clicaConhecimentoTransporte();
        lancamentoEntradaPages.clicarTipoCte();
        lancamentoEntradaPages.selecionarTipoCte();
        lancamentoEntradaFlows.salvarLancEntrada();
        lancamentoEntradaFlows.fechaNotaFiscal();
        String mensagemAtual = lancamentoEntradaPages.capturaMensagemFechamento();


        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);
        Assert.assertEquals(mensagemEsperada, mensagemAtual);

    }

    @Test
    public void edicaoDeNotaFiscalEntradaComChaveSemRelacionamento(){

            mainPage = new MainPage();
            loginflows = new LoginFlows();
            mainflows = new MainFlows();
            lancamentoEntradaFlows = new LancamentoEntradaFlows();
            lancamentoEntradaPages = new LancamentoEntradaPages();

            String chaveDeAcesso = DBSteps.retornaChaveCSV();
            String vencimento = lancamentoEntradaPages.getDataAtual();
            String statusEsperado = "Pendente";

            loginflows.efetuarLogin();
            mainflows.navegarParaLancamentoDeEntrada();
            lancamentoEntradaFlows.aplicarFiltro();
            lancamentoEntradaFlows.adicionarLancamento();
            lancamentoEntradaPages.preencherChave(chaveDeAcesso);
            lancamentoEntradaFlows.salvarLancEntrada();
            lancamentoEntradaFlows.preencheDataValidade();
            lancamentoEntradaFlows.confirmar();
            lancamentoEntradaFlows.fechaNotaFiscal();
            lancamentoEntradaPages.selecionaNotaFiscal();
            lancamentoEntradaFlows.editaVencimento(vencimento);
            lancamentoEntradaFlows.fechaNotaFiscal();
            lancamentoEntradaPages.popupRateio();
            String statusAtual = lancamentoEntradaPages.retornarStatusLancamento();
            Assert.assertEquals(statusEsperado, statusAtual);

            String nrLanctoNF = mainPage.capturaNrLanctoNf();
            DBSteps.deletaNF(nrLanctoNF);

    }

    @Test
    public void comparaProdutoNfComProdutoRelacionamento(){
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String chaveDeAcesso = DBSteps.retornaChaveCSVComparacao();
        String fornecedor = "Empresa Teste";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaPages.preencherChave(chaveDeAcesso);
        lancamentoEntradaFlows.salvarLancEntrada();
        lancamentoEntradaFlows.preencheDataValidade();
        lancamentoEntradaFlows.clicarConfirmar();
        lancamentoEntradaFlows.preencheDataValidade();
        lancamentoEntradaFlows.clicarConfirmar();
        String prodUm = lancamentoEntradaPages.comparaProdUm();
        String prodDois = lancamentoEntradaPages.comparaProdDois();
        String prodTres = lancamentoEntradaPages.comparaProdTres();
        lancamentoEntradaFlows.fechaNotaFiscal();
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);
        mainflows.navegarParaRelacionamentoDeItens();
        lancamentoEntradaFlows.filtroRelacionamentoProdXProdXml(fornecedor);
        String prodXmlUm = lancamentoEntradaPages.comparaProdXmlUm();
        String prodXmlDois = lancamentoEntradaPages.comparaProdXmlDois();
        String prodXmlTres = lancamentoEntradaPages.comparaProdXmlTres();
        Assert.assertEquals(prodUm, prodXmlUm);
        Assert.assertEquals(prodDois, prodXmlDois);
        Assert.assertEquals(prodTres, prodXmlTres);
    }

    @Test
    public void efetuarLancamentoNotaEntradaComChaveSimplesRemessa(){
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String chaveDeAcesso = DBSteps.retornaChaveSimplesRemessa();
        String cfopEsperado = "1901";
        String valorEsperado = "0,00";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaPages.clicaTpOperacao();
        lancamentoEntradaPages.selecionaTpOperacao();
        lancamentoEntradaPages.preencherChave(chaveDeAcesso);
        lancamentoEntradaFlows.salvarLancEntrada();
        lancamentoEntradaFlows.preencheDataValidade();
        lancamentoEntradaFlows.confirmar();
        lancamentoEntradaFlows.preencheDataValidade();
        lancamentoEntradaFlows.confirmar();
        lancamentoEntradaFlows.fecharNotaFiscal();
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        lancamentoEntradaPages.selecionaNotaFiscal();
        lancamentoEntradaPages.clicarAbaProduto();
        lancamentoEntradaPages.selecionaProduto();
        String cfop = lancamentoEntradaPages.retornaCfop();
        lancamentoEntradaPages.voltarTelaNf();
        lancamentoEntradaPages.clicarAbaCalcularImposto();
        String valorIcms = lancamentoEntradaPages.retornaIcms();
        String valorPis = lancamentoEntradaPages.retornaPis();
        String valorCofins = lancamentoEntradaPages.retornaCofins();
        String valorIpi = lancamentoEntradaPages.retornaIpi();
        Assert.assertEquals(cfop,cfopEsperado);
        Assert.assertEquals(valorIcms, valorEsperado);
        Assert.assertEquals(valorPis, valorEsperado);
        Assert.assertEquals(valorCofins, valorEsperado);
        Assert.assertEquals(valorIpi, valorEsperado);
        DBSteps.deletaNF(nrLanctoNF);
    }

    @Test
    public void efetuarLancamentoNotaEntradaComSucesso(){
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String remetente = "azevedo";
        String numero = "1234";
        String valor = "50";
        String quantidade = "5";
        String valorUnitario = "5";
        String produto = "AGUA MIN";
        String statusEsperado = "Aprovada";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaFlows.preencheNotaFiscalEntrada(remetente, numero, valor);
        lancamentoEntradaPages.clicarAbaProduto();
        lancamentoEntradaFlows.preencheProdutoGelf(quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaFlows.preencheProdutoAgua(produto, quantidade, valorUnitario);
        lancamentoEntradaPages.fecharNF();
        lancamentoEntradaPages.clicarConfirmaFechamento();
        lancamentoEntradaFlows.aprovarNotaEntrada();
        String status = lancamentoEntradaPages.retornaStatusAprovado();
        Assert.assertEquals(status, statusEsperado);
        lancamentoEntradaFlows.desaprovarNotaEntrada();
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);

    }

    @Test
    public void efetuarLancamentoNotaEntradaSemChaveMultiplosProdutos() {
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String remetente = "azevedo";
        String numero = "1234";
        String valor = "188,661";
        String quantidade = "2";
        String valorUnitario = "5";
        String produto = "AGUA MIN";
        String quantProd = "10,5874";
        String quantProd2 = "19,6999";
        String quantProd3= "5,4449";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaFlows.preencheNotaFiscalEntrada(remetente, numero, valor);
        lancamentoEntradaPages.clicarAbaProduto();
        lancamentoEntradaFlows.preencheProdutoAgua(produto, quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaPages.clicarAdicionarLancamento();
        lancamentoEntradaPages.clicarProdutoLupa();
        lancamentoEntradaPages.reload();
        lancamentoEntradaPages.selecionaCheckboxProdutoUm();
        lancamentoEntradaPages.selecionaCheckboxProdutoDois();
        lancamentoEntradaPages.selecionaCheckboxProdutoTres();
        lancamentoEntradaFlows.confirmar();
        lancamentoEntradaFlows.preencherQuantEValorMultiplosProdutos(quantProd, valorUnitario, quantProd2, quantProd3);
        lancamentoEntradaFlows.rastreabilidade();
        lancamentoEntradaFlows.fecharNotaFiscal();
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);
    }

    @Test
    public void validaParametroBloqueiaLançamentoDeProdutosDeEstoqueEmCompras() {
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String remetente = "azevedo";
        String numero = "5472";
        String valor = "52,50";
        String quantidade = "25";
        String valorUnitario = "1";
        String produto = "AGUA MIN";
        String produtoHela = "Hela Poult";
        String produtoPa = "pa de g";
        String produtoCebola = "cebola f";
        String alertaEsperado = "Produto de estoque não pode ser informado em NF de compra. Verificar parametrização.";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaFlows.aplicarFiltro();
        DBSteps.marcaParametroBloqueiaProdEst();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaFlows.preencheNotaFiscalEntrada(remetente, numero, valor);
        lancamentoEntradaPages.clicarAbaProduto();
        lancamentoEntradaFlows.preencheProdutoEstoqueAgua(produto);
        String alertaProdEstoqueAgua = lancamentoEntradaPages.capturaMensagemProdEstoque();
        lancamentoEntradaPages.popUpClicarEmOK();
        lancamentoEntradaFlows.preencheProdutoEstoqueHela(produtoHela);
        String alertaProdEstoqueHela = lancamentoEntradaPages.capturaMensagemProdEstoque();
        lancamentoEntradaPages.popUpClicarEmOK();
        lancamentoEntradaFlows.preencheProdutoCompraPa(produtoPa);
        lancamentoEntradaFlows.preencheDataValidade();
        lancamentoEntradaFlows.preencheDadosProduto(quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaFlows.preencheProdutoEstoqueAgua(produto);
        lancamentoEntradaPages.popUpClicarEmOK();
        lancamentoEntradaFlows.preencheProdutoCompraCebola(produtoCebola);
        lancamentoEntradaFlows.preencheDataValidade();
        lancamentoEntradaFlows.preencheDadosProduto(quantidade, valorUnitario);
        lancamentoEntradaFlows.fecharNotaFiscal();

        DBSteps.desmarcaParametroBloqueiaProdEst();
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);
        Assert.assertEquals(alertaProdEstoqueAgua, alertaEsperado);
        Assert.assertEquals(alertaProdEstoqueHela, alertaEsperado);
        Assert.assertEquals(alertaProdEstoqueAgua, alertaEsperado);
    }

    /*validar Lancamento Nota Entrada - Filial  Controla Estoque - sugere almoxarifado SIM
                                                Controla Lote
                                        Produto Controla Estoque
                                                Nao Controla Lote
                                         Controla Almoxarifado*/
    @Test
    public void validarLancamentoNotaEntradaProdutoControlaEstoqueNaoControlaLote() {
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String remetente = "azevedo";
        String numero = "7896";
        String valor = "485,46";
        String produto = "sucralo";
        String produtoPa = "pa de g";
        String almoxEsperado = "Almoxarifado";
        String valorAlmoxEsperado = "01";
        String quantidade = "10,293";
        String valorUnitario = "22,459";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaFlows.preencheNotaFiscalEntrada(remetente, numero, valor);
        lancamentoEntradaPages.clicarAbaProduto();
        lancamentoEntradaPages.clicarAdicionarLancamento();
        lancamentoEntradaPages.clicarFieldProduto();
        lancamentoEntradaPages.procuraProduto(produto);
        lancamentoEntradaPages.selecionaProdutoSucralose();
        String almoxarifado = lancamentoEntradaPages.retornaInfoComplementarAlmox();
        String valorAlmox = lancamentoEntradaPages.retornaAlmoxSelecionado();
        lancamentoEntradaFlows.preencheDadosProduto(quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaPages.clicarAdicionarLancamento();
        lancamentoEntradaPages.procuraProduto(produtoPa);
        lancamentoEntradaPages.selecionaProdutoCompraPa();
        lancamentoEntradaFlows.preencheDadosProduto(quantidade, valorUnitario);
        lancamentoEntradaFlows.fecharNotaFiscal();
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);
        Assert.assertEquals(almoxarifado, almoxEsperado);
        Assert.assertEquals(valorAlmox, valorAlmoxEsperado);

    }
    /*validar Lancamento Nota Entrada - Filial  Controla Estoque - sugere almoxarifado SIM
                                                Não Controla Lote
                                        Produto Controla Estoque
                                                Controla Lote
                                       Controla Almoxarifado*/
    @Test
    public void validarLancamentoNotaEntradaFilialControlaEstoqueENaoControlaLote() {
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String remetente = "azevedo";
        String numero = "7896";
        String valor = "462,34";
        String tituloEsperadoAlmox = "Almoxarifado/Localização";
        String quantidade = "10,293";
        String valorUnitario = "22,459";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaPages.clicaFieldUnidadeFiltro();
        lancamentoEntradaPages.selecionaUnidade0003Filtro(); //Utiliza filial 0003
        lancamentoEntradaFlows.aplicarFiltro();

        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaFlows.preencheNotaFiscalEntrada(remetente, numero, valor);
        String tituloAtualAlmox = lancamentoEntradaPages.retornaTituloALmox();
        lancamentoEntradaPages.clicaFieldAlmox();
        lancamentoEntradaPages.selecionaAlmox();
        lancamentoEntradaPages.btnConfirmarPopup();
        lancamentoEntradaPages.clicarAbaProduto();
        lancamentoEntradaPages.clicarAdicionarLancamento();
        lancamentoEntradaPages.clicarFieldProduto();
        lancamentoEntradaFlows.preencheProdutoHelaOx(quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaPages.clicarAdicionarLancamento();
        lancamentoEntradaPages.clicarFieldProduto();
        lancamentoEntradaFlows.preencheProdutoHummer(quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaPages.clicaRastreabilidade1();
        lancamentoEntradaPages.clicarConfirmar();
        lancamentoEntradaPages.clicaRastreabilidadeteste();
        lancamentoEntradaPages.clicarConfirmar();
        lancamentoEntradaFlows.fecharNotaFiscal();
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);
        Assert.assertEquals(tituloAtualAlmox, tituloEsperadoAlmox);

    }
    /*validar Lancamento Nota Entrada - Filial  Controla Estoque - sugere almoxarifado SIM
                                                Não Controla Lote
                                        Produto Não Controla Estoque
                                                Nao Controla Lote
                                        Controla Almoxarifado*/
    @Test
    public void validarLancamentoNotaEntradaFilialControlaEstoqueENaoControlaLoteProdNaoControlaEstoqueENaoControlaLote() {
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String remetente = "azevedo";
        String numero = "8749";
        String valor = "471,59";
        String tituloEsperadoAlmox = "Almoxarifado/Localização";
        String quantidade = "10,293";
        String valorUnitario = "22,459";
        String produto = "Agua min";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaPages.clicaFieldUnidadeFiltro();
        lancamentoEntradaPages.selecionaUnidade0003Filtro(); //Utiliza filial 0003
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaFlows.preencheNotaFiscalEntrada(remetente, numero, valor);
        String tituloAtualAlmox = lancamentoEntradaPages.retornaTituloALmox();
        lancamentoEntradaPages.clicaFieldAlmox();
        lancamentoEntradaPages.selecionaAlmox();
        lancamentoEntradaPages.btnConfirmarPopup();
        lancamentoEntradaPages.clicarAbaProduto();
        lancamentoEntradaPages.clicarAdicionarLancamento();
        lancamentoEntradaPages.clicarFieldProduto();
        lancamentoEntradaPages.selecionaProdutoGelf();
        lancamentoEntradaPages.clicarQuantidadeField(quantidade);
        lancamentoEntradaPages.clicarVrUnitario();
        lancamentoEntradaPages.informaVrUnitario(valorUnitario);
        lancamentoEntradaPages.salvarProd();
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaFlows.preencheProdutoAgua(produto, quantidade, valorUnitario);
        lancamentoEntradaFlows.fecharNotaFiscal();

        Assert.assertEquals(tituloAtualAlmox, tituloEsperadoAlmox);
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);

    }

   /* validar Lancamento Nota Entrada - Filial  Controla Estoque - sugere almoxarifado SIM
                                                Controla Lote
                                        Produto Não Controla Estoque
                                                Nao Controla Lote
                                        Controla Almoxarifado*/

    @Test
    public void validarLancamentoNotaEntradaFilialControlaEstoqueEControlaLoteProdNaoControlaEstoqueENaoControlaLote() {
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String remetente = "azevedo";
        String numero = "15263";
        String valor = "714,32";
        String quantidade = "10,293";
        String valorUnitario = "22,459";
        String produto = "Agua min";
        String produto2 = "Agua sanit";
        String mensagemEsperada = "Nota fechada com sucesso!";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaFlows.preencheNotaFiscalEntrada(remetente, numero, valor);
        lancamentoEntradaPages.clicarAbaProduto();
        lancamentoEntradaFlows.preencheProdutoGelf(quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaFlows.preencheProdutoAgua(produto, quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaFlows.preencheProdutoAguaSanitaria(produto2, quantidade, valorUnitario);
        lancamentoEntradaFlows.fecharNotaFiscal();
        String mensagemAtual = lancamentoEntradaPages.capturaMensagemFechamento();
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);
        Assert.assertEquals(mensagemEsperada, mensagemAtual);

    }

    /*validar Lancamento Nota Entrada - Filial  Controla Estoque  - sugere almoxarifado NÂO
                                                Não Controla Lote
                                        Produto Controla Estoque
                                                Controla Lote
                                       Controla Almoxarifado*/
    @Test
    public void validarLancamentoNotaEntradaNãoSugereAlmoxarifado() {
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String remetente = "azevedo";
        String numero = "7896";
        String valor = "462,34";
        String quantidade = "10,293";
        String valorUnitario = "22,459";
        String mensagemEsperada = "Nota fechada com sucesso!";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaPages.clicaFieldUnidadeFiltro();
        lancamentoEntradaPages.selecionaUnidade0003Filtro(); //Utiliza filial 0003
        lancamentoEntradaFlows.aplicarFiltro();
        DBSteps.desmarcaParamSugereAlmox();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaFlows.preencheNotaFiscalEntrada(remetente, numero, valor);
        lancamentoEntradaPages.clicarAbaProduto();
        lancamentoEntradaPages.clicarAdicionarLancamento();
        lancamentoEntradaPages.clicarFieldProduto();
        lancamentoEntradaPages.selecionaProdutoHelaOx(); // HelaOx
        lancamentoEntradaFlows.preencheDadosProduto(quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaPages.clicarAdicionarLancamento();
        lancamentoEntradaPages.clicarFieldProduto();
        lancamentoEntradaPages.selecionaProdutoHummer(); //Hummer
        lancamentoEntradaFlows.preencheDadosProduto(quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaPages.clicaRastreabilidade1();
        lancamentoEntradaPages.clicarConfirmar();
        lancamentoEntradaPages.clicaRastreabilidade2();
        lancamentoEntradaPages.clicarConfirmar();
        lancamentoEntradaFlows.fecharNotaFiscal();
        String mensagemAtual = lancamentoEntradaPages.capturaMensagemFechamento();
        DBSteps.marcaParamSugereAlmox();
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);
        Assert.assertEquals(mensagemEsperada, mensagemAtual);

    }
    /*validar Lancamento Nota Entrada - Filial  Controla Estoque - sugere almoxarifado SIM
                                                Controla Lote
                                        Produto Controla Estoque
                                                Controla Lote
                                            Não Controla Almoxarifado*/

    @Test
    public void validarLancamentoNotaEntradaNãoControlaAlmoxarifado() {
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String remetente = "azevedo";
        String numero = "125478";
        String valor = "204";
        String produto = "Agua Min";
        String quantidade = "10";
        String valorUnitario = "10";
        String mensagemEsperada = "Nota fechada com sucesso!";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaPages.clicaFieldUnidadeFiltro();
        lancamentoEntradaPages.selecionaUnidade0004Filtro(); //Utiliza filial 0004
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaFlows.preencheNotaFiscalEntrada(remetente, numero, valor);
        lancamentoEntradaPages.clicarAbaProduto();
        lancamentoEntradaFlows.preencheProdutoGelf(quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaFlows.preencheProdutoAgua(produto, quantidade, valorUnitario);
        lancamentoEntradaPages.salvarProd();
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaFlows.fecharNotaFiscal();
        String mensagemAtual = lancamentoEntradaPages.capturaMensagemFechamento();
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);
        Assert.assertEquals(mensagemEsperada, mensagemAtual);

    }

    @Test
    public void efetuarLancamentoNotaEntradaSemChaveSimplesRemessa() {
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String remetente = "azevedo";
        String numero = "7412";
        String valor = "50";
        String quantidade = "5";
        String valorUnitario = "5";
        String entradaOperacao = "Simples";
        String produto = "AGUA MIN";
        String statusEsperado = "Aprovada";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaPages.clicaOperacao();
        lancamentoEntradaPages.procuraOperacao(entradaOperacao);
        lancamentoEntradaPages.selecionaOperacaoSimplesRemessa(entradaOperacao);
        lancamentoEntradaFlows.preencheNotaFiscalEntrada(remetente, numero, valor);
        lancamentoEntradaPages.clicarAbaProduto();
        lancamentoEntradaFlows.preencheProdutoGelf(quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaFlows.preencheProdutoAgua(produto, quantidade, valorUnitario);
        lancamentoEntradaPages.fecharNF();
        lancamentoEntradaPages.clicarConfirmaFechamento();
        lancamentoEntradaFlows.aprovarNotaEntrada();
        String status = lancamentoEntradaPages.retornaStatusAprovado();
        Assert.assertEquals(status, statusEsperado);
        lancamentoEntradaFlows.desaprovarNotaEntrada();
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);

    }
    @Test
    public void efetuarLancamentoNotaEntradaSemChaveTransferencia() {
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String numero = "9874";
        String valor = "50";
        String quantidade = "5";
        String valorUnitario = "5";
        String produto = "AGUA MIN";
        String statusEsperado = "Aprovada";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaPages.clicaOperacao();
        lancamentoEntradaPages.selecionaOperacaoTransferencia();
        lancamentoEntradaPages.procuraRemetenteNfEntradaFiliEmit();
        lancamentoEntradaPages.selecionaRemetenteNfEntradaFiliEmit();
        lancamentoEntradaPages.clicaNumeroField();
        lancamentoEntradaPages.informaNumero(numero);
        lancamentoEntradaPages.clicaSerie();
        lancamentoEntradaPages.selecionaSerie();
        lancamentoEntradaPages.preencheValor(valor);
        lancamentoEntradaPages.clicarSalvarLancEntrada();
        lancamentoEntradaPages.clicarAbaProduto();
        lancamentoEntradaFlows.preencheProdutoGelf(quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaFlows.preencheProdutoAgua(produto, quantidade, valorUnitario);
        lancamentoEntradaPages.fecharNF();
        lancamentoEntradaPages.clicarConfirmaFechamento();
        lancamentoEntradaFlows.aprovarNotaEntrada();
        String status = lancamentoEntradaPages.retornaStatusAprovado();
        Assert.assertEquals(status, statusEsperado);
        lancamentoEntradaFlows.desaprovarNotaEntrada();
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);

    }
    @Test
    public void efetuarLancamentoNotaEntradaSemChaveComplemento() {
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String numero = "25478";
        String valor = "50";
        String quantidade = "5";
        String valorUnitario = "5";
        String produto = "AGUA MIN";
        String statusEsperado = "Aprovada";
        String remetente = "azevedo";
        String mensagemDadosAdicionais = "Nota de Origem: 000001646 (Emissao: 20/09/2022 Total: 1075.02 )";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaPages.clicaOperacao();
        lancamentoEntradaPages.selecionaOperacaoComplemento();
        lancamentoEntradaFlows.preencheNotaFiscalEntrada(remetente, numero, valor);
        lancamentoEntradaPages.clicarAbaProduto();
        lancamentoEntradaFlows.preencheProdutoGelfSemControleDeEstoque(quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaFlows.preencheProdutoAgua(produto, quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaPages.clicaAbaDadosAdicionaisEntrada();
        lancamentoEntradaPages.clicaAdicionarDadosAdicionaisEntrada();
        lancamentoEntradaPages.clicaMensagemDadosAdicionaisEntrada();
        lancamentoEntradaPages.fecharNF();
        lancamentoEntradaPages.clicarConfirmaFechamento();
        lancamentoEntradaFlows.aprovarNotaEntrada();
        String status = lancamentoEntradaPages.retornaStatusAprovado();
        Assert.assertEquals(status, statusEsperado);
        lancamentoEntradaFlows.desaprovarNotaEntrada();
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);

    }
    /*validar Lancamento Nota Entrada - Filial  Controla Estoque - sugere almoxarifado SIM
                                                Não Controla Lote
                                        Produto Controla Estoque
                                                Controla Lote
                                       Controla Almoxarifado*/
    @Test
    public void validarLancamentoNotaEntradaComChaveFilialControlaEstoqueENaoControlaLote() {
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String chaveDeAcesso = DBSteps.retornaChaveCSVLote();
        String mensagemEsperada = "Nota fechada com sucesso!";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaPages.clicaFieldUnidadeFiltro();
        lancamentoEntradaPages.selecionaUnidade0003Filtro();
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaPages.preencherChave(chaveDeAcesso);
        lancamentoEntradaFlows.salvarLancEntrada();
        lancamentoEntradaPages.clicarConfirmarInfoComplementar();
        lancamentoEntradaPages.clicarConfirmarInfoComplementar();
        lancamentoEntradaPages.clicarEmCancelarEntrada();

        lancamentoEntradaPages.clicarAcoesEntrada();
        lancamentoEntradaPages.clicarFecharNFAcoes();
        lancamentoEntradaPages.clicarConfirmaFechamento();
        lancamentoEntradaPages.popUpClicarEmOK();
        lancamentoEntradaPages.tabMensagemFechamento();
        lancamentoEntradaPages.clicarConfirmaFechamento();

        String mensagemAtual = lancamentoEntradaPages.capturaMensagemFechamento();
        Assert.assertEquals(mensagemEsperada, mensagemAtual);
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        //DBSteps.deletaNF(nrLanctoNF);

    }
    /*validar Lancamento Nota Entrada - Filial  Controla Estoque - sugere almoxarifado NÃO
                                               Não Controla Lote
                                       Produto Controla Estoque
                                               Controla Lote
                                      Controla Almoxarifado*/
    @Test
    public void validarLancamentoNotaEntradaComChaveFilialControlaEstoqueENaoControlaLoteNãoSugereAlmoxarifado() {
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String chaveDeAcesso = DBSteps.retornaChaveCSVLote();
        String mensagemEsperada = "Nota fechada com sucesso!";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        //DBSteps.desmarcaParamSugereAlmox();
        lancamentoEntradaPages.clicaFieldUnidadeFiltro();
        lancamentoEntradaPages.selecionaUnidade0003Filtro();
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaPages.preencherChave(chaveDeAcesso);
        lancamentoEntradaFlows.salvarLancEntrada();
        lancamentoEntradaPages.clicarConfirmarInfoComplementar();
        lancamentoEntradaPages.clicarConfirmarInfoComplementar();
        lancamentoEntradaFlows.fechaNotaFiscal();
        String mensagemAtual = lancamentoEntradaPages.capturaMensagemFechamento();

        Assert.assertEquals(mensagemEsperada, mensagemAtual);
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
       // DBSteps.deletaNF(nrLanctoNF);
       // DBSteps.marcaParamSugereAlmox();

    }

    /*validar Lancamento Nota Entrada - Filial  Controla Estoque - sugere almoxarifado NãO
                                                Controla Lote
                                        Produto Controla Estoque
                                                Controla Lote
                                            Não Controla Almoxarifado*/
    @Test
    public void validarLancamentoNotaEntradaComChaveNãoControlaAlmoxarifado() {
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String chaveDeAcesso = DBSteps.retornaChaveCSVAlmox();
        String mensagemEsperada = "Nota fechada com sucesso!";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        lancamentoEntradaPages.clicaFieldUnidadeFiltro();
        lancamentoEntradaPages.selecionaUnidade0004Filtro(); //Utiliza filial 0004
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaPages.preencherChave(chaveDeAcesso);
        lancamentoEntradaFlows.salvarLancEntrada();
        lancamentoEntradaPages.rastreabilidadeHela();
        lancamentoEntradaPages.infoComplementarProd(DATA_VALIDADE);
        lancamentoEntradaPages.clicarConfirmar();
        //lancamentoEntradaPages.clicarConfirmarInfoComplementar();
        //lancamentoEntradaPages.clicarConfirmarInfoComplementar();
        lancamentoEntradaFlows.fechaNotaFiscal();
        String mensagemAtual = lancamentoEntradaPages.capturaMensagemFechamento();

        Assert.assertEquals(mensagemEsperada, mensagemAtual);
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        //DBSteps.deletaNF(nrLanctoNF);
    }
    
    @Test
    public void validaParametroBloqueiaLançamentoDeProdutosDeEstoqueEmComprasComChave() {
        mainPage = new MainPage();
        loginflows = new LoginFlows();
        mainflows = new MainFlows();
        lancamentoEntradaFlows = new LancamentoEntradaFlows();
        lancamentoEntradaPages = new LancamentoEntradaPages();

        String chaveDeAcesso = DBSteps.retornaChaveCSVProdutoEstoque();
        String numero = "5472";
        String valor = "52,50";
        String quantidade = "25";
        String valorUnitario = "1";
        String produto = "AGUA MIN";
        String produtoHela = "Hela Poult";
        String produtoPa = "pa de g";
        String produtoCebola = "cebola f";
        String alertaEsperado = "Produto de estoque não pode ser informado em NF de compra. Verificar parametrização.";

        loginflows.efetuarLogin();
        mainflows.navegarParaLancamentoDeEntrada();
        DBSteps.marcaParametroBloqueiaProdEst();
        lancamentoEntradaFlows.aplicarFiltro();
        lancamentoEntradaFlows.adicionarLancamento();
        lancamentoEntradaPages.preencherChave(chaveDeAcesso);
        lancamentoEntradaFlows.salvarLancEntrada();
        lancamentoEntradaPages.clicarAbaProduto();
        lancamentoEntradaFlows.preencheProdutoEstoqueAgua(produto);
        String alertaProdEstoqueAgua = lancamentoEntradaPages.capturaMensagemProdEstoque();
        lancamentoEntradaPages.popUpClicarEmOK();
        lancamentoEntradaFlows.preencheProdutoEstoqueHela(produtoHela);
        String alertaProdEstoqueHela = lancamentoEntradaPages.capturaMensagemProdEstoque();
        lancamentoEntradaPages.popUpClicarEmOK();
        lancamentoEntradaFlows.preencheProdutoCompraPa(produtoPa);
        lancamentoEntradaFlows.preencheDataValidade();
        lancamentoEntradaFlows.preencheDadosProduto(quantidade, valorUnitario);
        lancamentoEntradaPages.voltarTelaProduto();
        lancamentoEntradaFlows.preencheProdutoEstoqueAgua(produto);
        lancamentoEntradaPages.popUpClicarEmOK();
        lancamentoEntradaFlows.preencheProdutoCompraCebola(produtoCebola);
        lancamentoEntradaFlows.preencheDataValidade();
        lancamentoEntradaFlows.preencheDadosProduto(quantidade, valorUnitario);
        lancamentoEntradaFlows.fecharNotaFiscal();

        DBSteps.desmarcaParametroBloqueiaProdEst();
        String nrLanctoNF = mainPage.capturaNrLanctoNf();
        DBSteps.deletaNF(nrLanctoNF);
        Assert.assertEquals(alertaProdEstoqueAgua, alertaEsperado);
        Assert.assertEquals(alertaProdEstoqueHela, alertaEsperado);
        Assert.assertEquals(alertaProdEstoqueAgua, alertaEsperado);
    }


}